pub struct FleetFacts {
pub name: String,
pub members: Vec<AgentFacts>,
pub budget_usd: f64,
pub authorized: bool,
}Expand description
One fleet plus the members that give it its abilities. A fleet declares no capabilities of its own — it has exactly what its members have.
Fields
name: Stringmembers: Vec<AgentFacts>budget_usd: f64Implementations
Sourceimpl FleetFacts
impl FleetFacts
pub fn blocker(&self) -> Option<Blocker>
Sourcepub fn members_with(&self, bin: &str) -> Vec<&AgentFacts>
pub fn members_with(&self, bin: &str) -> Vec<&AgentFacts>
The members that could actually run bin.