pub enum DetectMethod {
File {
file: String,
},
Command {
command: String,
},
Version {
version: VersionCheck,
},
}Expand description
Exactly one detection method (serde picks the arm by which field is present).
Variants
File
A file exists at this (tilde/$MUR_HOME-expanded) path.
Command
A command resolves on PATH.
Version
A command’s reported version is >= min.
Fields

version: VersionCheckTrait Implementations
Sourceimpl Clone for DetectMethod
impl Clone for DetectMethod
Sourcefn clone(&self) -> DetectMethod
fn clone(&self) -> DetectMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DetectMethod
impl Debug for DetectMethod
Sourceimpl<'de> Deserialize<'de> for DetectMethod
impl<'de> Deserialize<'de> for DetectMethod
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DetectMethod
impl JsonSchema for DetectMethod
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DetectMethod
impl PartialEq for DetectMethod
Sourceimpl Serialize for DetectMethod
impl Serialize for DetectMethod
impl StructuralPartialEq for DetectMethod