pub struct ArchiveSpec {
pub members: Vec<RecipeMember>,
}Fields
members: Vec<RecipeMember>Trait Implementations
Sourceimpl Clone for ArchiveSpec
impl Clone for ArchiveSpec
Sourcefn clone(&self) -> ArchiveSpec
fn clone(&self) -> ArchiveSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArchiveSpec
impl Debug for ArchiveSpec
Sourceimpl<'de> Deserialize<'de> for ArchiveSpec
impl<'de> Deserialize<'de> for ArchiveSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArchiveSpec
impl JsonSchema for ArchiveSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArchiveSpec
impl PartialEq for ArchiveSpec
Sourceimpl Serialize for ArchiveSpec
impl Serialize for ArchiveSpec
impl StructuralPartialEq for ArchiveSpec