pub struct PlatformRecipe {
pub url: String,
pub sha256: String,
pub install_to: Option<String>,
pub executable: bool,
pub archive: Option<ArchiveSpec>,
}Fields
url: Stringsha256: Stringinstall_to: Option<String>Bare-binary install target (relative to mur_home); None when archive.
executable: boolarchive: Option<ArchiveSpec>Trait Implementations
Sourceimpl Clone for PlatformRecipe
impl Clone for PlatformRecipe
Sourcefn clone(&self) -> PlatformRecipe
fn clone(&self) -> PlatformRecipe
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlatformRecipe
impl Debug for PlatformRecipe
Sourceimpl<'de> Deserialize<'de> for PlatformRecipe
impl<'de> Deserialize<'de> for PlatformRecipe
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlatformRecipe
impl JsonSchema for PlatformRecipe
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PlatformRecipe
impl PartialEq for PlatformRecipe
Sourceimpl Serialize for PlatformRecipe
impl Serialize for PlatformRecipe
impl StructuralPartialEq for PlatformRecipe