ModelRegistry

Struct ModelRegistry 

pub struct ModelRegistry {
    pub schema_version: u32,
    pub models: BTreeMap<String, ModelEntry>,
    pub roles: BTreeMap<String, RoleEntry>,
}

Fields

schema_version: u32models: BTreeMap<String, ModelEntry>roles: BTreeMap<String, RoleEntry>

Implementations

Source

impl ModelRegistry

pub fn load_from(path: &Path) -> Result<Self>

pub fn save_to(&self, path: &Path) -> Result<()>

pub fn default_path() -> Result<PathBuf>

pub fn resolve_role(&self, role: &str) -> Option<&str>

Return the primary model ID for role, or the fallback if the primary is not in the models map, or None if the role is not configured.