verify_subjects

Function verify_subjects 

pub fn verify_subjects(
    statement: &InTotoStatement,
    tarball_files: &[(String, Vec<u8>)],
) -> Result<(), MuragentError>
Verify that every subject in the statement exists in the tarball with matching hash, and every tarball file (excluding EXCLUDED_FILES) is listed.