pub enum SignalKind {
ExecutionSuccess,
ExecutionFailure {
error: String,
},
UserOverrideAtBreakpoint {
reason: Option<String>,
},
AutoFixApplied {
step: String,
},
NewPatternProposal {
origin_context: String,
},
}Expand description
What happened to the target.
Variants
ExecutionSuccess
Workflow/step using this pattern completed successfully. (Channel 1)
ExecutionFailure
Workflow/step using this pattern failed. (Channel 1)
UserOverrideAtBreakpoint
User rejected a breakpoint while this pattern was active. (Channel 1, 3x weight)
AutoFixApplied
AutoFix ran on a step that used this pattern. (Channel 1, signals pattern inadequacy)
NewPatternProposal
Proposal to add a new pattern. (Channel 2 — chat extraction, Channel 3 — procedural)