pub struct SkillGene {
pub triggers: BTreeSet<TriggerGene>,
pub steps: Vec<StepGene>,
pub requires: BTreeMap<String, String>,
pub mcp: BTreeSet<McpGene>,
}Fields
triggers: BTreeSet<TriggerGene>steps: Vec<StepGene>requires: BTreeMap<String, String>requirement name -> semver constraint string (as written in the manifest; parsed lazily by the Union semver merger).
mcp: BTreeSet<McpGene>Implementations
Sourceimpl SkillGene
impl SkillGene
pub fn from_manifest(m: &SkillManifest) -> Result<Self, GeneError>
Sourcepub fn to_procedure(&self) -> Procedure
pub fn to_procedure(&self) -> Procedure
Rebuild a Procedure from the steps in this gene (preserves order,
no variables — Variables are copied from the keeper manifest by the
orchestrator, not the gene layer).
pub fn to_triggers(&self) -> Vec<Trigger>
pub fn to_requirements(&self) -> Vec<Requirement>
pub fn to_mcp_requirements(&self) -> Vec<McpRequirement>