Module fleet

Module fleet 

Fleet — a named squad of agents working a shared goal over one channel.

Structs

Fleet
FleetLoop

Constants

CHANNEL_PREFIX
Channel-id prefix for a fleet’s shared channel (fleet-<name>).
CONCIERGE_AGENT

Functions

fleet_name_from_channel_id
Derive the fleet name from a channel id of the form fleet-<name>.
valid_fleet_name
A fleet name must be a filesystem-safe lowercase slug (it becomes a directory ~/.mur/fleets/<name> and a channel id fleet-<name>).