Fleet — a named squad of agents working a shared goal over one channel.
Structs
Constants
- CHANNEL_
PREFIX - Channel-id prefix for a fleet’s shared channel (
fleet-<name>). - CONCIERGE_
AGENT
Functions
- fleet_
name_ from_ channel_ id - Derive the fleet name from a channel id of the form
fleet-<name>. - valid_
fleet_ name - A fleet name must be a filesystem-safe lowercase slug (it becomes a directory
~/.mur/fleets/<name>and a channel idfleet-<name>).