pub fn verify_subjects(
statement: &InTotoStatement,
tarball_files: &[(String, Vec<u8>)],
) -> Result<(), MuragentError>Expand description
Verify that every subject in the statement exists in the tarball with matching hash, and every tarball file (excluding EXCLUDED_FILES) is listed.